@@ -1,6 +1,8 @@
 '''Functions for plotting degradation and soiling analysis results.'''
 
 import matplotlib.pyplot as plt
+import pandas as pd
+import plotly.express as px
 import numpy as np
 import warnings
 
@@ -9,7 +11,7 @@ def degradation_summary_plots(yoy_rd, yoy_ci, yoy_info, normalized_yield,
                               hist_xmin=None, hist_xmax=None, bins=None,
                               scatter_ymin=None, scatter_ymax=None,
                               plot_color=None, summary_title=None,
-                              scatter_alpha=0.5):
+                              scatter_alpha=0.5, detailed=False):
     '''
     Create plots (scatter plot and histogram) that summarize degradation
     analysis results.
@@ -29,7 +31,7 @@ def degradation_summary_plots(yoy_rd, yoy_ci, yoy_info, normalized_yield,
           a probability given by the ``exceedance_prob`` parameter in
           the :py:func:`.degradation.degradation_year_on_year`
 
-    normalized_yield : pd.Series
+    normalized_yield : pandas.Series
          PV yield data that is normalized, filtered and aggregated
     hist_xmin : float, optional
         lower limit of x-axis for the histogram
@@ -48,6 +50,10 @@ def degradation_summary_plots(yoy_rd, yoy_ci, yoy_info, normalized_yield,
         overall title for summary plots
     scatter_alpha : float, default 0.5
         Transparency of the scatter plot
+    detailed : bool, optional
+        Color code points by the number of times they get used in calculating
+        Rd slopes.  Default color: 2 times (as a start and endpoint). Green:
+        1 time. Red: 0 times.
 
     Note
     ----
@@ -56,7 +62,7 @@ def degradation_summary_plots(yoy_rd, yoy_ci, yoy_info, normalized_yield,
 
     Returns
     -------
-    fig : matplotlib Figure
+    fig : matplotlib.figure.Figure
         Figure with two axes
     '''
 
@@ -67,6 +73,9 @@ def degradation_summary_plots(yoy_rd, yoy_ci, yoy_info, normalized_yield,
 
     bins = int(min(bins, len(yoy_values)))
 
+    if plot_color is None:
+        plot_color = 'C0'
+
     # Calculate the degradation line
     start = normalized_yield.index[0]
     end = normalized_yield.index[-1]
@@ -92,8 +101,13 @@ def degradation_summary_plots(yoy_rd, yoy_ci, yoy_info, normalized_yield,
     ax2.set_xlabel('Annual degradation (%)')
 
     renormalized_yield = normalized_yield / yoy_info['renormalizing_factor']
-    ax1.plot(renormalized_yield.index, renormalized_yield, 'o',
-             color=plot_color, alpha=scatter_alpha)
+    if detailed:
+        colors = yoy_info['usage_of_points'].map({0: 'red', 1: 'green', 2: plot_color})
+    else:
+        colors = plot_color
+    ax1.scatter(renormalized_yield.index, renormalized_yield,
+                c=colors, alpha=scatter_alpha)
+
     ax1.plot(x, y, 'k--', linewidth=3)
     ax1.set_xlabel('Date')
     ax1.set_ylabel('Renormalized energy')
@@ -126,7 +140,7 @@ def soiling_monte_carlo_plot(soiling_info, normalized_yield, point_alpha=0.5,
     soiling_info : dict
         ``soiling_info`` returned by :py:meth:`.soiling.SRRAnalysis.run` or
         :py:func:`.soiling.soiling_srr`.
-    normalized_yield : pd.Series
+    normalized_yield : pandas.Series
         PV yield data that is normalized, filtered and aggregated.
     point_alpha : float, default 0.5
         tranparency of the ``normalized_yield`` points
@@ -146,7 +160,7 @@ def soiling_monte_carlo_plot(soiling_info, normalized_yield, point_alpha=0.5,
 
     Returns
     -------
-    fig : matplotlib Figure
+    fig : matplotlib.figure.Figure
     '''
     warnings.warn(
         'The soiling module is currently experimental. The API, results, '
@@ -189,7 +203,7 @@ def soiling_interval_plot(soiling_info, normalized_yield, point_alpha=0.5,
     soiling_info : dict
         ``soiling_info`` returned by :py:meth:`.soiling.SRRAnalysis.run` or
         :py:func:`.soiling.soiling_srr`.
-    normalized_yield : pd.Series
+    normalized_yield : pandas.Series
         PV yield data that is normalized, filtered and aggregated.
     point_alpha : float, default 0.5
         tranparency of the ``normalized_yield`` points
@@ -206,7 +220,7 @@ def soiling_interval_plot(soiling_info, normalized_yield, point_alpha=0.5,
 
     Returns
     -------
-    fig : matplotlib Figure
+    fig : matplotlib.figure.Figure
     '''
     warnings.warn(
         'The soiling module is currently experimental. The API, results, '
@@ -246,7 +260,7 @@ def soiling_rate_histogram(soiling_info, bins=None):
 
     Returns
     -------
-    fig : matplotlib Figure
+    fig : matplotlib.figure.Figure
     '''
     warnings.warn(
         'The soiling module is currently experimental. The API, results, '
@@ -256,14 +270,65 @@ def soiling_rate_histogram(soiling_info, bins=None):
 
     soiling_summary = soiling_info['soiling_interval_summary']
     fig, ax = plt.subplots()
-    ax.hist(100.0 * soiling_summary.loc[soiling_summary['valid'], 'soiling_rate'],
-            bins=bins)
+    ax.hist(100.0 * soiling_summary.loc[soiling_summary['valid'],
+                                        'soiling_rate'], bins=bins)
     ax.set_xlabel('Soiling rate (%/day)')
     ax.set_ylabel('Count')
 
     return fig
 
 
+def tune_filter_plot(signal, mask, display_web_browser=False):
+    """
+    This function allows the user to visualize filtered data in
+    a Plotly plot, after tweaking the function's different
+    parameters. The plot of signal colored according to mask
+    can be zoomed in on, for an in-depth look.
+
+    Parameters
+    ----------
+    signal : pandas.Series
+        Index of the Pandas series is a Pandas datetime index. Usually
+        this is PV power or energy, but other signals will work.
+    mask : pandas.Series
+        Pandas series of booleans, where included data periods
+        are marked as True, and omitted-data periods occurs are
+        marked as False. Should have the same detetime index as signal.
+    display_web_browser : boolean, default False
+        When set to True, the Plotly graph is displayed in the
+        user's web browser.
+
+    Returns
+    ---------
+    Interactive Plotly graph, with the masked time series for the filter.
+    """
+    # Get the names of the series and the datetime index
+    column_name = signal.name
+    if column_name is None:
+        column_name = 'signal'
+        signal = signal.rename(column_name)
+    index_name = signal.index.name
+    if index_name is None:
+        index_name = 'datetime'
+        signal = signal.rename_axis(index_name)
+    # Visualize the power_ac time series, delineating clipping periods
+    # using the clipping_mask series. Use plotly to visualize.
+    df = pd.DataFrame(signal)
+    # Add the mask as a column
+    df['mask'] = mask
+    df = df.reset_index()
+    fig = px.scatter(df, x=index_name, y=column_name, color='mask',
+                     color_discrete_map={
+                         True: "blue",
+                         False: "goldenrod"},
+                     )
+    # If display_web_browser is set to True, the time series with clipping
+    # is rendered via the web browser.
+    if display_web_browser is True:
+        fig.show(renderer="browser")
+    return fig
+
+
 def availability_summary_plots(power_system, power_subsystem, loss_total,
                                energy_cumulative, energy_expected_rescaled,
                                outage_info):
@@ -282,28 +347,28 @@ def availability_summary_plots(power_system, power_subsystem, loss_total,
 
     Parameters
     ----------
-    power_system : pd.Series
+    power_system : pandas.Series
         Timeseries total system power.
 
-    power_subsystem : pd.DataFrame
+    power_subsystem : pandas.DataFrame
         Timeseries power data, one column per subsystem.
 
-    loss_total : pd.Series
+    loss_total : pandas.Series
         Timeseries system lost power.
 
-    energy_cumulative : pd.Series
+    energy_cumulative : pandas.Series
         Timeseries system cumulative energy.
 
-    energy_expected_rescaled : pd.Series
+    energy_expected_rescaled : pandas.Series
         Timeseries expected energy, rescaled to match actual energy. This
         reflects interval energy, not cumulative.
 
-    outage_info : pd.DataFrame
+    outage_info : pandas.DataFrame
         A dataframe with information about system outages.
 
     Returns
     -------
-    fig : matplotlib Figure
+    fig : matplotlib.figure.Figure
 
     See Also
     --------
